@@ -18,7 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """List Command Module."""
-
+from __future__ import annotations
 
 import logging
 
@@ -30,6 +30,7 @@ from rich.table import Table
 
 from molecule import scenarios, text, util
 from molecule.command import base
+from molecule.command.base import MOLECULE_GLOB
 from molecule.console import console
 from molecule.status import Status
 
@@ -63,7 +64,7 @@ def list(ctx, scenario_name, format):  # type: ignore[no-untyped-def] # pragma:
 
     statuses = []
     s = scenarios.Scenarios(
-        base.get_configs(args, command_args, glob_str="**/molecule/*/molecule.yml"),  # type: ignore[no-untyped-call]
+        base.get_configs(args, command_args, glob_str=MOLECULE_GLOB),
         scenario_name,
     )
     for scenario in s:
