@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Matrix Command Module."""
+from __future__ import annotations
 
 import logging
 
@@ -77,5 +78,5 @@ def matrix(ctx, scenario_name, subcommand):  # type: ignore[no-untyped-def] # pr
     args = ctx.obj.get("args")
     command_args = {"subcommand": subcommand}
 
-    s = scenarios.Scenarios(base.get_configs(args, command_args), scenario_name)  # type: ignore[no-untyped-call]
+    s = scenarios.Scenarios(base.get_configs(args, command_args), scenario_name)
     s.print_matrix()  # type: ignore[no-untyped-call]
