@@ -18,14 +18,15 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Config Module."""
+from __future__ import annotations
 
 import copy
 import logging
 import os
 import warnings
 
-from collections.abc import MutableMapping
 from pathlib import Path
+from typing import TYPE_CHECKING
 from uuid import uuid4
 
 from ansible_compat.ports import cache, cached_property
@@ -40,6 +41,10 @@ from molecule.provisioner import ansible
 from molecule.util import boolean
 
 
+if TYPE_CHECKING:
+    from collections.abc import MutableMapping
+
+
 LOG = logging.getLogger(__name__)
 MOLECULE_DEBUG = boolean(os.environ.get("MOLECULE_DEBUG", "False"))
 MOLECULE_VERBOSITY = int(os.environ.get("MOLECULE_VERBOSITY", 0))
