@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Base Ansible Galaxy dependency module."""
+from __future__ import annotations
 
 import abc
 import copy
@@ -32,7 +33,11 @@ LOG = logging.getLogger(__name__)
 
 
 class AnsibleGalaxyBase(base.Base):
-    """Ansible Galaxy dependency base class."""
+    """Ansible Galaxy dependency base class.
+
+    Attributes:
+        FILTER_OPTS: Keys to remove from the dictionary returned by options().
+    """
 
     __metaclass__ = abc.ABCMeta
 
